@@ -1,8 +1,9 @@
 use 5.006;
 use strict;
 use warnings;
+
 package Metabase::Resource::metabase::fact;
-our $VERSION = '0.021'; # VERSION
+our $VERSION = '0.023'; # VERSION
 
 use Carp ();
 
@@ -10,41 +11,41 @@ use Metabase::Resource::metabase;
 our @ISA = qw/Metabase::Resource::metabase/;
 
 sub _metadata_types {
-  return {
-    guid => '//str',
-  };
+    return { guid => '//str', };
 }
 
 sub _init {
-  my ($self) = @_;
-  my ($guid) = $self =~ m{\Ametabase:[^:]+:(.+)\z};
-  Carp::confess("could not determine guid from '$self'\n")
-    unless defined $guid && length $guid;
-  $self->_add( guid => $guid);
-  return $self;
+    my ($self) = @_;
+    my ($guid) = $self =~ m{\Ametabase:[^:]+:(.+)\z};
+    Carp::confess("could not determine guid from '$self'\n")
+      unless defined $guid && length $guid;
+    $self->_add( guid => $guid );
+    return $self;
 }
 
 sub validate {
-  my $self = shift;
-  $self->_validate_guid( $self->guid );
-  return 1;
+    my $self = shift;
+    $self->_validate_guid( $self->guid );
+    return 1;
 }
 
 1;
 
 # ABSTRACT: class for Metabase facts
 
-
+__END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Metabase::Resource::metabase::fact - class for Metabase facts
 
 =head1 VERSION
 
-version 0.021
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -96,15 +97,10 @@ H.Merijn Brand <hmbrand@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by David Golden.
+This software is Copyright (c) 2013 by David Golden.
 
 This is free software, licensed under:
 
   The Apache License, Version 2.0, January 2004
 
 =cut
-
-
-__END__
-
-
