@@ -1,8 +1,9 @@
 use 5.006;
 use strict;
 use warnings;
+
 package Metabase::Resource::perl::commit;
-our $VERSION = '0.021'; # VERSION
+our $VERSION = '0.023'; # VERSION
 
 use Carp ();
 
@@ -10,32 +11,30 @@ use Metabase::Resource::perl;
 our @ISA = qw/Metabase::Resource::perl/;
 
 sub _metadata_types {
-  return {
-    sha1          => '//str',
-  };
+    return { sha1 => '//str', };
 }
 
 sub _init {
-  my ($self) = @_;
+    my ($self) = @_;
 
-  my ($string) = $self =~ m{\Aperl:///commit/(.+)\z};
-  Carp::confess("could not determine commit from '$self'\n")
-    unless defined $string && length $string;
+    my ($string) = $self =~ m{\Aperl:///commit/(.+)\z};
+    Carp::confess("could not determine commit from '$self'\n")
+      unless defined $string && length $string;
 
-  my $sha1 = $1;
-  Carp::confess("illegal commit hash")
-    unless $sha1 =~ m/^[a-f0-9]+$/;
+    my $sha1 = $1;
+    Carp::confess("illegal commit hash")
+      unless $sha1 =~ m/^[a-f0-9]+$/;
 
-  $self->_add( 'sha1' => $sha1 );
+    $self->_add( 'sha1' => $sha1 );
 
-  return $self;
+    return $self;
 }
 
 
 sub full_url {
-  my ($self, $host) = @_;
-  $host ||= 'perl5.git.perl.org';
-  return "http://${host}/perl.git/" . $self->sha1;
+    my ( $self, $host ) = @_;
+    $host ||= 'perl5.git.perl.org';
+    return "http://${host}/perl.git/" . $self->sha1;
 }
 
 # 'commit' validates during _init, really
@@ -46,17 +45,19 @@ sub validate { 1 }
 
 # ABSTRACT: class for Metabase resources about perl commits
 
-
+__END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Metabase::Resource::perl::commit - class for Metabase resources about perl commits
 
 =head1 VERSION
 
-version 0.021
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -122,18 +123,10 @@ H.Merijn Brand <hmbrand@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by David Golden.
+This software is Copyright (c) 2013 by David Golden.
 
 This is free software, licensed under:
 
   The Apache License, Version 2.0, January 2004
 
 =cut
-
-
-__END__
-
-
-
-
-
